export interface DeviceModeFunctionVO {
  /**
   * 设备模型功能ID
   */
  modeFunctionId: string | number;

  /**
   * 设备模型ID，关联表hw_device_mode的device_mode_id
   */
  deviceModeId: string | number;

  /**
   * 功能模式（1、属性，2、服务，3、事件）
   */
  functionMode: string;

  /**
   * 坐标标识（1、经度，2、纬度）
   */
  coordinate: string;

  /**
   * 功能名称
   */
  functionName: string;

  /**
   * 标识符（支持大小写字母、数字和下划线，对外暂时不超过50个字符）
   */
  functionIdentifier: string | number;

  /**
   * 功能类型(1、直采变量 2、手录变量 3、运算性变量)
   */
  functionType: string;

  /**
   * 数据类型（2、int，4、float，5、double，6、binary(image/base64),9、bool，10、string）
   */
  dataType: number;

  /**
   * 数据定义
   */
  dataDefinition: string;

  /**
   * 运算性变量公式（标识符1*标识符2*100）
   */
  functionFormula: string;

  /**
   * 单位
   */
  propertyUnit: string;

  /**
   * 显示标识（0、不显示，1、显示，2、可累积显示）
   */
  displayFlag: string;

  /**
   * 读写标识（1、读写，2、只读）
   */
  rwFlag: string;

  /**
   * 调用方式（1、异步，2、同步），当功能模式为服务时必填
   */
  invokeMethod: string;

  /**
   * 事件类型（1、信息，2、告警，3、故障），当功能类型为事件时必填
   */
  eventType: string;

  /**
   * 描述
   */
  remark: string;

  /**
   * 获取公式
   */
  acquisitionFormula: string;

  /**
   * 预留字段，顺序
   */
  orderFlag: number;

  /**
   * 预留字段，寄存器
   */
  deviceRegister: string;

  /**
   * 预留字段，步长
   */
  propertyStep: number;

  /**
   * 预留字段
   */
  propertyField: string;

}

export interface DeviceModeFunctionForm extends BaseEntity {
  /**
   * 设备模型功能ID
   */
  modeFunctionId?: string | number;

  /**
   * 设备模型ID，关联表hw_device_mode的device_mode_id
   */
  deviceModeId?: string | number;

  /**
   * 功能模式（1、属性，2、服务，3、事件）
   */
  functionMode?: string;

  /**
   * 坐标标识（1、经度，2、纬度）
   */
  coordinate?: string;

  /**
   * 功能名称
   */
  functionName?: string;

  /**
   * 标识符（支持大小写字母、数字和下划线，对外暂时不超过50个字符）
   */
  functionIdentifier?: string | number;

  /**
   * 功能类型(1、直采变量 2、手录变量 3、运算性变量)
   */
  functionType?: string;

  /**
   * 数据类型（2、int，4、float，5、double，6、binary(image/base64),9、bool，10、string）
   */
  dataType?: number;

  /**
   * 数据定义
   */
  dataDefinition?: string;

  /**
   * 运算性变量公式（标识符1*标识符2*100）
   */
  functionFormula?: string;

  /**
   * 单位
   */
  propertyUnit?: string;

  /**
   * 显示标识（0、不显示，1、显示，2、可累积显示）
   */
  displayFlag?: string;

  /**
   * 读写标识（1、读写，2、只读）
   */
  rwFlag?: string;

  /**
   * 调用方式（1、异步，2、同步），当功能模式为服务时必填
   */
  invokeMethod?: string;

  /**
   * 事件类型（1、信息，2、告警，3、故障），当功能类型为事件时必填
   */
  eventType?: string;

  /**
   * 描述
   */
  remark?: string;

  /**
   * 获取公式
   */
  acquisitionFormula?: string;

  /**
   * 预留字段，顺序
   */
  orderFlag?: number;

  /**
   * 预留字段，寄存器
   */
  deviceRegister?: string;

  /**
   * 预留字段，步长
   */
  propertyStep?: number;

  /**
   * 预留字段
   */
  propertyField?: string;

  inputParametersData?: [];
  outputParametersData?: [];

}

export interface DeviceModeFunctionQuery extends PageQuery {

  /**
   * 设备模型功能ID
   */
  modeFunctionId?: string | number;

  /**
   * 设备模型ID，关联表hw_device_mode的device_mode_id
   */
  deviceModeId?: string | number;

  /**
   * 功能模式（1、属性，2、服务，3、事件）
   */
  functionMode?: string;

  /**
   * 坐标标识（1、经度，2、纬度）
   */
  coordinate?: string;

  /**
   * 功能名称
   */
  functionName?: string;

  /**
   * 标识符（支持大小写字母、数字和下划线，对外暂时不超过50个字符）
   */
  functionIdentifier?: string | number;

  /**
   * 功能类型(1、直采变量 2、手录变量 3、运算性变量)
   */
  functionType?: string;

  /**
   * 数据类型（2、int，4、float，5、double，6、binary(image/base64),9、bool，10、string）
   */
  dataType?: number;

  /**
   * 数据定义
   */
  dataDefinition?: string;

  /**
   * 运算性变量公式（标识符1*标识符2*100）
   */
  functionFormula?: string;

  /**
   * 单位
   */
  propertyUnit?: string;

  /**
   * 显示标识（0、不显示，1、显示，2、可累积显示）
   */
  displayFlag?: string;

  /**
   * 读写标识（1、读写，2、只读）
   */
  rwFlag?: string;

  /**
   * 调用方式（1、异步，2、同步），当功能模式为服务时必填
   */
  invokeMethod?: string;

  /**
   * 事件类型（1、信息，2、告警，3、故障），当功能类型为事件时必填
   */
  eventType?: string;

  /**
   * 获取公式
   */
  acquisitionFormula?: string;

  /**
   * 预留字段，顺序
   */
  orderFlag?: number;

  /**
   * 预留字段，寄存器
   */
  deviceRegister?: string;

  /**
   * 预留字段，步长
   */
  propertyStep?: number;

  /**
   * 预留字段
   */
  propertyField?: string;

    /**
     * 日期范围参数
     */
    params?: any;
}



